/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.display;

/**
 * 
 * @author Ian Burnett
 */
public interface Window
{
    
    /**
     * Returns the width of the text area in characters.
     * 
     * @return
     */
    public int getWidth();
    
    /**
     * Returns the height of the text area in characters.
     * 
     * @return
     */
    public int getHeight();
    
    /**
     * Creates a text area region at the location specified. 
     * 
     * @param x x co-ordinate in characters. Zero-based, counted
     * left to right.
     * @param y y co-ordinate in characters. Zero-based, counted
     * top to bottom.
     * @param w Width of the text area in characters. 
     * @param h Height of the text area in characters.
     * 
     * @return A new {@link TextArea} region of the dimensions and
     * location specified.
     */
    public TextArea createTextArea(int x, int y, int w, int h);
    
    
}
