/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.entity;

/**
 * An overall type which represents an entity in the system, which
 * can be controlled or monitored.
 * 
 * @author Ian Burnett
 */
public interface Entity
{
    /**
     * Returns the numeric ID which the provider can use to
     * uniquely refer to this entity.
     * 
     * @return An integer device ID
     */
    public int getID();
    
    /**
     * Returns the entity name as specified in the configuration file.
     * 
     * @return A non-null String containing the name in the config file.
     * This does not necessarily mean anything to the entity provider.
     */
    public String getName();
}
