/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.entity.fan;



/**
 * An interface which extends the simple Fan interface to permit a
 * suitably-authorised module to control the power level of a given
 * fan.
 * 
 * @author Ian Burnett
 */
public interface ControlledFan extends Fan
{
    /**
     * Sets the power level of the fan.
     * 
     * @param percentage A numeric in the range 0-100 inclusive.
     * Zero represents fully off, 100 represents fully on. A
     * fan may not necessarily be able to precisely control power
     * output, and in this case any value > 0 should be treated as
     * the fan being switched on.
     */
    public void setFanPowerLevel(int percentage);
}
