/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.entity.fan;


public interface FanProvider
{
    public void addMonitoredFan(Fan f);
    
    /**
     * \brief Sets the specified fan to a given power level.
     *
     * Fan power is expressed as a percentage and the value supplied must be in
     * the range 0 to 100 inclusive.
     *
     * \param pDriverInstData Driver instance data as supplied by a call to the 
     * driver_Create() function.
     *
     * \param fan_id ID of the fan to adjust power output in the device. This is
     * zero-based.
     *
     * \param nPower 0 &lt;= nPower &lt;= 100, where 0 is off and 100 is fully on
     *
     * \retval int zero on success, non-zero otherwise.
     */
   public void setFanPower(int nFan, int nPower);

}
