/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.entity.keypad;

/**
 * A class should implement this interface if they are connected to a
 * keypad device.
 * 
 * @author Ian Burnett
 */
public interface KeyProvider
{
    /**
     * Adds a key listener to the object. Adding a key listener already
     * added to the object is silently ignored. No guarantees are made
     * on the order with which key actions are reported.
     * 
     * @param listener The non-null listener object.
     * 
     * @throws NullPointerException If listener is null.
     */
    public void addKeyListener(KeyListener listener);
    
    /**
     * Removes the key listener from the object.
     * 
     * @param listener The key listener object to remove. Removing
     * a key listener which is not already present is silently
     * ignored. 
     * 
     * @throws NullPointerException If listener is null.
     */
    public void removeKeyListener(KeyListener listener);
}
