/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.entity.led;

import com.ianburnett.iilc.entity.Entity;

/**
 * Represents a physical LED as presented by a hardware interface module.
 * 
 * @author Ian Burnett
 */
public interface ControlledLED extends Entity
{
    /**
     * Retrieves the colour last set on the physical device.
     * 
     * @return An IILCColour object containing the last colour as set
     * on this device. Returns null if no value has yet been set.
     */
    public Color getCurrentColour();
    
    /**
     * Sets the LED to a particular value.
     * 
     * @param colour The IILCColour object representing the component
     * parts of the new LED colour.
     */
    public void setColour(Color colour);
}
