/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.entity.led;



public interface LEDProvider
{
    /**
     * \brief Sets the specified LED to the given colour.
     *
     * Colour is expressed as a percentage of the three primary additive colours.
     * Each of these values must be in the range 0 to 100 inclusive. An
     * implementation should ignore a colour component if the LED device cannot
     * render that specific colour.
     *
     * \param pDriverInstData Driver instance data as supplied by a call to the 
     * driver_Create() function.
     *
     * \param led_id ID of the LED to change in the device. This is zero-based.
     *
     * \param nRed 0 &lt;= nRed &lt;= 100, where 0 is off and 100 is fully on
     *
     * \param nGreen 0 &lt;= nGreen &lt;= 100, where 0 is off and 100 is fully on
     *
     * \param nBlue 0 &lt;= nBlue &lt;= 100, where 0 is off and 100 is fully on
     *
     * \retval int zero on success, non-zero otherwise.
     * @param color TODO
     */
   public void setLED(ControlledLED led, Color color);

   public void addMonitoredLED(ControlledLED led);
}
