/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.entity.temp;

import com.ianburnett.iilc.entity.Entity;

/**
 * Represents a temperature sensor which is installed within the
 * currently-configured system.
 * 
 * @author Ian Burnett
 */
public interface TempSensor extends Entity
{
    /**
     * This method should be called whenever a change in the current
     * temperature is detected.
     * 
     * @param degreesC The current temperature in degrees celcius.
     */
    public void reportTemperature(double degreesC);
    
    /**
     * Used to obtain the last known temperature as reported by this
     * sensor.
     * 
     * @return The last temperature as reported to the
     * {@link #reportTemperature(double)} method. 
     */
    public double getCurrentTemperature();
}
