/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.impl;

import java.util.HashMap;
import java.util.Map;

import com.ianburnett.iilc.Module;

/**
 * Provides a simple abstract stub implementation of the Module
 * interface.
 * 
 * 
 * @author Ian Burnett
 */
public abstract class ModuleImpl implements Module
{
    /**
     * A map of all options set on the module.
     */
    private Map _options = null;
    
    /**
     * Default constructor.
     */
    public ModuleImpl()
    {
        this._options = new HashMap();
    }

    /**
     * 
     */
    public void setOption(String key, String value)
    {
        _options.put(key, value);
    }       
    
    /**
     * 
     * @param key
     * @return
     */
    protected String getOption(String key)
    {
        return (String) _options.get(key);
    }

    /**
     * Default update interval for a module is every 2 seconds.
     * 
     * @see Module#getUpdateInterval()
     */
    public int getUpdateInterval()
    {
        return 2000;
    }

    /**
     * Simple no-op implementation of the initialisation routine.
     * 
     * @see Module#init()
     */
    public void init()
    {
        
    }
    
    /**
     * Simple no-op implementation of the start routine.
     * 
     * @see Module#start()
     */
    public void start()
    {
        
    }
    
    /**
     * Simple no-op implementation of the stop routine.
     * 
     * @see Module#stop()
     */
    public void stop()
    {
        
    }
    
    public void destroy()
    {
        
    }
    
    public int getHardwareVersionMajor()
    {
        return -1;
    }
    
    
    public int getHardwareVersionMinor()
    {
        return -1;
    }

}
