/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.server;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;

import com.ianburnett.iilc.server.parser.ASTConfigFile;
import com.ianburnett.iilc.server.parser.ASTDisplayDecl;
import com.ianburnett.iilc.server.parser.ASTModuleDecl;
import com.ianburnett.iilc.server.parser.Node;

class ConfigFile
{
    /**
     * 
     */
    private HashMap _cfgModules = null;
    
    /**
     * 
     */
    private HashMap _cfgDisplays = null;
    
    /**
     * 
     * @param astFile
     */
    public ConfigFile(ASTConfigFile astFile)
    {
        // HashMap to store the modules defined in the config file
        this._cfgModules = new HashMap();
        
        // HashMap to store the displays defined in the config file 
        this._cfgDisplays = new HashMap();
        
        // Walk over each child entry we find
        int numChildren = astFile.jjtGetNumChildren();
        for (int i = 0; i < numChildren; i++) {

            // Get the node itself
            Node n = astFile.jjtGetChild(i);
            
            // Decide on type and create new child object
            if (n instanceof ASTModuleDecl) {
                ConfigModule cfgModule = new ConfigModule((ASTModuleDecl) n);
                _cfgModules.put(cfgModule.getName(), cfgModule);
            }
            else if (n instanceof ASTDisplayDecl) {
                ConfigDisplay cfgDisplay = new ConfigDisplay((ASTDisplayDecl) n);
                _cfgDisplays.put(cfgDisplay.getName(), cfgDisplay);
            }
        }
    }

    public ConfigModule getModule(String name)
    {
        return (ConfigModule) _cfgModules.get(name);
    }
    
    public Set getModuleNames()
    {
        return _cfgModules.keySet();
    }
    
    public ConfigDisplay getDisplay(String name)
    {
        return (ConfigDisplay) _cfgDisplays.get(name);
    }
    
    public Set getDisplayNames()
    {
        return _cfgDisplays.keySet();
    }
    
    public void validate()
    {
        // Walk over each child module, performing its own validation
        Iterator iterM = _cfgModules.keySet().iterator();
        while (iterM.hasNext()) {
            String strModuleName = (String) iterM.next();
            ConfigModule cfgModule = (ConfigModule) _cfgModules.get(strModuleName);
            cfgModule.validate(this);
        }
        
        // ... now for each display
        Iterator iterD = _cfgDisplays.keySet().iterator();
        while (iterD.hasNext()) {
            String strDisplayName = (String) iterD.next();
            ConfigDisplay cfgDisplay = (ConfigDisplay) _cfgDisplays.get(strDisplayName);
            cfgDisplay.validate(this);
        }
    }
    
    public void warning(String message)
    {
        System.out.println("WARNING: " + message);
        
    }
    
    public void error(String message)
    {
        System.out.println("ERROR  : " + message);
        
    }

}
