/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.server;

import com.ianburnett.iilc.server.parser.ASTOptionDirective;
import com.ianburnett.iilc.server.parser.ASTStringLiteral;
import com.ianburnett.iilc.server.parser.Node;

/**
 * Class to encapsulate an option set on a particular module in the
 * configuration file. Each instance represents an option, stored as
 * String key/value pair. 
 * 
 * @author Ian Burnett
 */
class ConfigOption
{
    private String _key;
    
    private String _value;
    
    /**
     * Constructor which converts an AST object into a fully-configured
     * ConfigOption object.
     * 
     * @param astOption
     */
    public ConfigOption(ASTOptionDirective astOption)
    {
        // Get both children
        Node child1 = astOption.jjtGetChild(0);
        Node child2 = astOption.jjtGetChild(1);

        // First child is the key, second is the value
        this._key   = ((ASTStringLiteral) child1).toString();
        this._value = ((ASTStringLiteral) child2).toString();
    }
    
    /**
     * Returns the key for this key/value pair.
     * 
     * @return The non-null string as specified in the config file.
     */
    public String getKey()
    {
        return _key;
    }
    
    /**
     * Returns the value for this key/value pair.
     * 
     * @return The non-null string as specified in the config file.
     */
    public String getValue()
    {
        return _value;
    }
}
