/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.server;

import com.ianburnett.iilc.server.parser.ASTReportDirective;
import com.ianburnett.iilc.server.parser.ASTStringLiteral;
import com.ianburnett.iilc.server.parser.Node;

class ConfigReport
{
    private String _reportingModule;
    
    private String _reportingName;
    
    /**
     * The definition in the config tree this control request refers to.
     */
    private ConfigDefine _cfgDefine;
    

    ConfigReport(ASTReportDirective astReport)
    {
        // Get all the children objects
        Node child1 = astReport.jjtGetChild(0);
        Node child2 = astReport.jjtGetChild(1);

        // First object is the module providing the data
        _reportingModule = ((ASTStringLiteral) child1).toString();
        
        // Second child is the object within that module
        _reportingName = ((ASTStringLiteral) child2).toString();
    }
    
    public String getReportingModule()
    {
        return _reportingModule;
    }
    
    public String getReportingName()
    {
        return _reportingName;
    }
    
    /**
     * Retrieves the definition this control object refers to.
     * 
     * @return
     */
    public ConfigDefine getDefinition()
    {
        return _cfgDefine;
    }
    
    
    /**
     * Performs checks to ensure this object is correctly configured.
     * 
     * @param cfgFile
     * @param cfgModule
     * 
     * @return true to indicate success, false otherwise.
     */
    public boolean validate(ConfigFile cfgFile, ConfigModule cfgModule)
    {
        // Look up the definition in the main file
        ConfigModule cfgTargetModule = cfgFile.getModule(_reportingModule);
        if (cfgTargetModule == null) {
            cfgFile.warning("Module '" + _reportingModule +
                    "' does not exist in the config file - ignored");
            return false;
        }
        
        // Look up the definition in the module
        _cfgDefine = cfgTargetModule.getEntityDefinition(_reportingName);
        if (_cfgDefine == null) {
            cfgFile.error("No such definition " + _reportingName +
                    " in module " + _reportingModule);
            return false;
        }
        
//      // Check this module can receive these reports
//      switch (cfgDefine.getDefineType()) {
//          
//      // Fan listeners must implement the correct interface
//      case ConfigDefine.DEFINE_TYPE_FAN:
//          if ( ! FanListener.class.isAssignableFrom(_implClass) ) {
//              cfgFile.warning("Module '" + _name +
//                      "' not declared to accept fan reports - ignoring");
//              iterReports.remove();
//              continue;
//          }
//          break;
//          
//      // Temp listeners must implement the correct interface
//      case ConfigDefine.DEFINE_TYPE_TEMP:
//          if ( ! TempListener.class.isAssignableFrom(_implClass) ) {
//              cfgFile.warning("Module '" + _name +
//              "' not declared to accept temp reports - ignoring");
//              iterReports.remove();
//              continue;
//          }
//          break;
//          
//      // LEDs don't make sense to receive reports
//      case ConfigDefine.DEFINE_TYPE_LED:
//          cfgFile.warning("LEDs do not provide status reports - ignoring");
//          iterReports.remove();
//          continue;
//      
//      }

        // All ok
        return true;
    }
    
    
    
}
