/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.server;

import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

import com.ianburnett.iilc.InvalidConfigurationException;
import com.ianburnett.iilc.Module;
import com.ianburnett.iilc.display.DisplayProvider;
import com.ianburnett.iilc.server.parser.ASTScreenDecl;
import com.ianburnett.iilc.server.parser.ASTStringLiteral;
import com.ianburnett.iilc.server.parser.ASTWindowDecl;
import com.ianburnett.iilc.server.parser.Node;

class ConfigScreen
{
    private String _name;
    
    private final Set _cfgWindows = new HashSet();
    
    /**
     * 
     * @param astScreen
     */
    ConfigScreen(ASTScreenDecl astScreen)
    {
        // First child is the screen name
        Node child1 = astScreen.jjtGetChild(0);
        _name = ((ASTStringLiteral) child1).toString();
        
        // Each subsequent child is a window declaration
        int numChildren = astScreen.jjtGetNumChildren();
        for (int i = 1; i < numChildren; i++) {
         
            // Get the child node 
            Node n = astScreen.jjtGetChild(i);
            
            // Decide on the type and action
            if (n instanceof ASTWindowDecl) {
                
                // Create a window for this screen to control
                ConfigWindow cfgWindow = new ConfigWindow((ASTWindowDecl) n);
                
                // Add this to the collection of windows we encapsulate
                _cfgWindows.add(cfgWindow);
            }
        }
        
    }
    
    public void validate(ConfigFile cfgFile)
    {
        // Validate each of the windows we encapsulate
        Iterator iter = _cfgWindows.iterator();
        while (iter.hasNext()) {
            ConfigWindow cfgWindow = (ConfigWindow) iter.next();
            cfgWindow.validate(cfgFile);
        }
    }
    
    private ScreenImpl _screen;

    /**
     * 
     * @return
     * @throws InvalidConfigurationException
     */
    ScreenImpl getInstance() throws InvalidConfigurationException
    {
        // Create a new screen
        _screen = new ScreenImpl();
        
        // Create a window object for each module wishing to control this screen
        Iterator iter = _cfgWindows.iterator();
        while (iter.hasNext()) {
            
            // Get the config object
            ConfigWindow cfgWindow = (ConfigWindow) iter.next();
            
            // Create an instance
            WindowImpl window = cfgWindow.getInstance();
            
            // Get all the information from the config instance
            
            // Add to the screen object
            _screen.addWindow(window);
        }
        
        // Return the configured screen
        return _screen;
    }

}
