/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.server;

import com.ianburnett.iilc.entity.led.Color;
import com.ianburnett.iilc.entity.led.ControlledLED;
import com.ianburnett.iilc.entity.led.LEDProvider;

/**
 * Internal implementation of the ControlledLED interface.
 * 
 * @author Ian Burnett
 */
class ControlledLEDImpl extends EntityImpl implements ControlledLED
{
    private LEDProvider _lp = null;
    
    private int _nRed;
    
    private int _nGreen;
    
    private int _nBlue;
    
    /**
     * 
     * @param deviceID
     * @param name
     */
    ControlledLEDImpl(int deviceID, String name)
    {
        super(deviceID, name);
    }

    /**
     * @see ControlledLED#getCurrentColour()
     */
    public Color getCurrentColour()
    {
        return new Color(_nRed, _nGreen, _nBlue);
    }

    /**
     * @see ControlledLED#setColour(Color)
     */
    public void setColour(Color colour)
    {
        // Update internally
        _nRed   = colour.r;
        _nGreen = colour.g;
        _nBlue  = colour.b;
        
        // Fire request to provider
        _lp.setLED(this, colour);
    }

    /**
     * 
     * @param provider
     */
    void setProvider(LEDProvider provider)
    {
        this._lp = provider;
    }
    
}
