/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.server;

import com.ianburnett.iilc.entity.fan.ControlledFan;
import com.ianburnett.iilc.entity.fan.Fan;

/**
 * Simple implementation of Fan as used internally. This is
 * actually a wrapper of ControlledFanImpl, designed to prevent
 * modules from accidentally casting to be of type ControlledFan
 * (which is what could happen if we only provided one
 * implementation).
 * 
 * @author Ian Burnett
 */
class FanImpl extends EntityImpl implements Fan
{
    /**
     * The delegate object.
     */
    private ControlledFan _fan;
    
    /**
     * Creates an instance of a fan which is not controlled, but
     * simply uses the ControlledFan instance as a delegate object.
     * 
     * @param fan A valid ControlledFan instance.
     */
    FanImpl(ControlledFan fan)
    {
        super(fan.getID(), fan.getName());
        this._fan = fan;
    }
        
    /**
     * Delegates to the object used when constructing this instance.
     * 
     * @see Fan#getCurrentPowerLevel()
     */
    public int getCurrentPowerLevel()
    {
        return _fan.getCurrentPowerLevel();
    }

    /**
     * Delegates to the object used when constructing this instance.
     * 
     * @see Fan#getCurrentRPM()
     */
    public int getCurrentRPM()
    {
        return _fan.getCurrentRPM();
    }

    /**
     * Delegates to the object used when constructing this instance.
     * 
     * @see Fan#reportFanSpeed(int)
     */
    public void reportFanSpeed(int rpm)
    {
        _fan.reportFanSpeed(rpm);
    }

}
