/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.server;

import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

/**
 * 
 * @author Ian Burnett
 *
 */
class ScreenImpl
{
    private final Set _windows = new HashSet();
    
    public void addWindow(WindowImpl window)
    {
        _windows.add(window);
    }

    public void render(char[][] output)
    {
        // Each screen defaults to blank spaces
        for (int r = 0; r < output.length; r++) {
            for (int c = 0; c < output[0].length; c++) {
                output[r][c] = ' ';
            }
        }
        
        // Iterate over each window, rendering into the buffer
        Iterator iter = _windows.iterator();
        while (iter.hasNext()) {
            
            WindowImpl window = (WindowImpl) iter.next();
            
            // Get size detail & create a buffer to render into
            int h = window.getHeight();
            int w = window.getWidth();
            int x = window.getX();
            int y = window.getY();
            char[][] buffer = new char[h][w];
            
            // Render the buffer
            window.render(buffer);
            
            // Copy into our output buffer
            for (int r = 0; r < h; r++) {
                System.arraycopy(buffer[r], 0, output[y + r], x, w);
            }
        }
    }
}
