/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.server;

import com.ianburnett.iilc.entity.temp.TempSensor;
import com.ianburnett.iilc.entity.temp.TempSensorProvider;

/**
 * Internal implementation of a temperature sensor.
 * 
 * @author Ian Burnett
 */
class TempImpl extends EntityImpl implements TempSensor
{
    /**
     * The last temperature reported by this sensor. Initially
     * set to {@link Double#MAX_VALUE}. 
     */
    private double _lastTemp = Double.MAX_VALUE;
    
    /**
     * The provider of this temperature sensor.
     */
    private TempSensorProvider _tempProvider;
    
    /**
     * 
     * @param id
     * @param name
     */
    public TempImpl(int id, String name) 
    {
        super(id, name);
    }

    /**
     * @see TempSensor#reportTemperature(double)
     */
    public void reportTemperature(double degreesC)
    {
        _lastTemp = degreesC;
    }

    /**
     * @see TempSensor#getCurrentTemperature()
     */
    public double getCurrentTemperature()
    {
        return _lastTemp;
    }
    
    /**
     * @param provider
     */
    void setProvider(TempSensorProvider provider)
    {
        this._tempProvider = provider;
    }
}
