/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.server;

import com.ianburnett.iilc.display.TextArea;
import com.ianburnett.iilc.display.WindowRegion;

/**
 * Internal implementation of the {@link TextArea} interface.
 *  
 * @author Ian Burnett
 */
class TextAreaImpl implements TextArea
{
    /**
     * Width of this text area in characters.
     */
    private final int _width;
    
    /**
     * Height of this text area in characters.
     */
    private final int _height;
    
    /**
     * The current text of the text area.
     */
    private final String[] _strText;
    
    /**
     * 
     * @param width
     * @param height
     */
    TextAreaImpl(int width, int height)
    {
        _width = width;
        _height = height;
        _strText = new String[height];
    }
    
    /**
     * @see TextArea#setText(int, String)
     */
    public void setText(int row, String text)
    {
        _strText[row] = text;
    }

    /**
     * @see WindowRegion#render(char[][])
     */
    public void render(char[][] output)
    {
        for (int r = 0; r < _height; r++) {
            char[] cText = _strText[r].toCharArray();
            int nTextLen = cText.length;
            if (nTextLen < _width) {
                System.arraycopy(cText, 0, output[r], 0, nTextLen);
                for (int c = nTextLen; c < _width; c++) {
                    output[r][c] = ' ';
                }
            }
            else {
                System.arraycopy(cText, 0, output[r], 0, _width);
            }
        }        
    }
}
