/*
 * Copyright Ian Burnett 2005, 2006.
 *
 * This file is part of Ian's Interactive LCD controller (IILC).
 *
 * IILC is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * IILC is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with IILC; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

package com.ianburnett.iilc.server.utils;

/**
 *
 * 
 * @author Ian Burnett
 */
public class Event
{
    public static final int TYPE_NOT_DEFINED          = 0xFF; 
    public static final int TYPE_NO_OP                = 0x00;
    public static final int TYPE_TEXT_SCROLL          = 0x01;
    public static final int TYPE_KEY_PRESS            = 0x02;
    public static final int TYPE_KEY_RELEASE          = 0x03;
    public static final int TYPE_LED_UPDATE           = 0x04;
    public static final int TYPE_SCREEN_CLEAR         = 0x05;
    public static final int TYPE_SCREEN_CHANGE        = 0x06;
    public static final int TYPE_SCREEN_REFRESH       = 0x07;
    public static final int TYPE_SET_BACKLIGHT        = 0x08;
    public static final int TYPE_ENABLE_TEMP_REPORT   = 0x09;
    public static final int TYPE_DISABLE_TEMP_REPORT  = 0x0A;
    public static final int TYPE_ENABLE_FAN_REPORT    = 0x0B;
    public static final int TYPE_DISABLE_FAN_REPORT   = 0x0C;
    public static final int TYPE_SET_FAN_STATE        = 0x0D;
    public static final int TYPE_SHUTDOWN             = 0x0E;
    public static final int TYPE_POLL_MODULE          = 0x0F;
    public static final int TYPE_SET_CONTRAST         = 0x10;
    public static final int TYPE_POLL_LED_STATUS      = 0x11;

    private int _type = -1;
    
    private Object[] _data = null;
    
    /**
     * 
     * @return
     */
    public int getType()
    {
        return _type;
    }

    /**
     * 
     * @param type
     */
    public Event(int type)
    {
        this(type, new Object[] { } );
    }
    
    /**
     * 
     * @param type
     * @param data
     */
    public Event(int type, int data)
    {
        this(type, new Object[] { new Integer(data) } );
    }
    
    /**
     * 
     * @param type
     * @param data
     */
    public Event(int type, String data)
    {
        this(type, new Object[] { new String(data) } );
    }
    
    /**
     * 
     * @param type
     * @param data
     */
    public Event(int type, Object data)
    {
        this(type, new Object[] { data } );
    }
    
    /**
     * 
     * @param type
     * @param data
     */
    public Event(int type, Object[] data) {
        this._type = type;
        this._data = data;
    }
    
    /**
     * 
     * @return
     */
    public int getIntData()
    {
        return getIntData(0);
    }
    
    /**
     * 
     * @param index
     * @return
     */
    public int getIntData(int index)
    {
        Integer iData = (Integer) getObjectData(index);
        return iData.intValue();
    }
    
    /**
     * 
     * @return
     */
    public Object getObjectData()
    {
        return getObjectData(0);
    }
    
    /**
     * 
     * @param index
     * @return
     */
    public Object getObjectData(int index)
    {
        if (index >= _data.length) {
            throw new ArrayIndexOutOfBoundsException(index + " >= " + _data.length);
        }
        else if (index < 0) {
            throw new ArrayIndexOutOfBoundsException(index + " < 0");
        }
        else {
            return _data[index];
        }
    }
}
